# Plugins

Surfactant supports using plugins to add additional features. For users, installing and enabling a plugin usually just involves doing a `pip install .` from within the folder for the plugin. Some plugins may also be available on PyPI, and can be pip installed using their package name.

Currently, controlling which plugins run can be done by pip installing and pip uninstalling the plugins. Additional plugin management and configuration option features are a work in progress.

Detailed information on configuration options for the plugin system and how to develop new plugins can be found [here](./docs/plugins.md).
